==> hubzero-cms-1.3.1_1.3.1.2.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.2/cms/HUBZERO-CREDITS.php <==
<?php
/**
 * @package     hubzero-cms
 * @copyright   Copyright (c) 2005-2011 Purdue University. All rights reserved.
 * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

/**
 * HUBzero includes or is derivative of works distributed under the licenses listed below.
 *
 * CMS - Joomla!
 *
 * @author		Open Source Matters
 * @copyright	Copyright (C) 2005 - 2010 Open Source Matters. All rights reserved.
 * @license:	GNU/GPL, see lICENSE.php
 * @version		1.5.22
 * @link		http://joomlacode.org/gf/download/frsrelease/10547/41305/Joomla_1.5.12-Stable-Full_Package.zip
 *
 * Library - Open Flash Chart
 *
 * @package		Open Flash Chart
 * @copyright	Copyright (C) 2007 John Glazebrook
 * @license:	GNU/LGPL 2.1
 * @version:	2.0 (Hyperion)
 * @link		http://sourceforge.net/projects/openflashchart/files/open-flash-chart/open-flash-chart-2-hyperion.zip/download
 *
 * @package		SWFObject
 * @copuright	Copyright (c) 2007 Geoff Stearns, Michael Williams, and Bobby van der Sluis
 * @license     http://www.opensource.org/licenses/mit-license.php
 * @version		2.0
 * @link		http://code.google.com/p/swfobject/
 *
 * @package     Services_JSON
 * @author      Michal Migurski <mike-json@teczno.com>
 * @author      Matt Knapp <mdknapp[at]gmail[dot]com>
 * @author      Brett Stimmerman <brettstimmerman[at]gmail[dot]com>
 * @copyright   2005 Michal Migurski
 * @version     CVS: $Id: JSON.php,v 1.31 2006/06/28 05:54:17 migurski Exp $
 * @license     http://www.opensource.org/licenses/bsd-license.php
 * @link        http://pear.php.net/pepr/pepr-proposal-show.php?id=198
 *
 * @package		as3corelib
 * @copyright	Copyright(c) 2005 Adobe Systems Incorporated. All rights reserved.
 * @license		Adobe Systems Incorporated(r) Source Code License Agreement
 * @link		http://code.google.com/p/as3corelib/downloads/list
 *
 * @package		Equations - Main equations for the Tweener class
 * @author		Zeh Fernando, Nate Chatellier
 * @version		1.0.2
 * @license		MIT
 *
 * @package		Easing Equations
 * @author		Robert Penner
 * @copyright	Copyright 2001 Robert Penner. All rights reserved.
 * @license		Open source under the BSD License.
 *
 * @package 	Tweener
 * @author      Zeh Fernando, Nate Chatellier, Arthur Debert
 * @copuright	Copyright (c) 2006-2007 Zeh Fernando and Nate Chatellier
 * @version     1.26.62
 * @license		MIT
 *
 * @package		JSON
 * @author		Alcaraz Marc
 * @author		Trannie Carter
 * @copyright	Copyright (c) 2005 JSON.org
 * @version     1.0.0.0
 * @link		http://www.ekameleon.net
 *
 * Library - FPDF
 *
 * @package		fpdf
 * @author		Oliver Plathey
 * @license		permissive
 * @link		http://www.fpdf.org
 *
 * Library - NUSOAP
 *
 * @package		nusoap
 * @author		Dietrich Ayala
 * @author		Scott Nichol
 * @author		Ingo Fischer
 * @copyright	Copyright (c) 2002 NuSphere Corporation
 * @version		0.7.3
 * @license		LGPL
 *
 * Library - CAS
 *
 * @package		phpCAS
 * @author      Pascal Aubry.
 * @copyright	Copyright © 2003-2008, The ESUP-Portail consortium & the JA-SIG Collaborative. All rights reserved
 * @version		1.0.1
 * @license		BSD
 *
 * @package		domxml-php4-php5
 * @author		Alexandre Alapetite
 * @copyright	Copyright 2004
 * @license		Creative Commons "Attribution-ShareAlike 2.0 France" BY-SA (FR)
 * @link		http://alexandre.alapetite.net/doc-alex/domxml-php4-php5/
 *
 * CSS - Reset
 *
 * @package		reset css
 * @file		templates/hubbasic/css/reset.css
 * @copyright	Copyright (c) 2006, Yahoo! Inc. All rights reserved.
 * @license		Code licensed under the BSD License:
 * @link		http://developer.yahoo.net/yui/license.txt
 * @version		0.11.3
 *
 * Javascript - Calendar
 *
 * @package 	Javascript - Calendar
 * @file		components/com_events/calendar.css
 * @file		components/com_events/js/calendar.rc4.js
 * @author		Aeron Glemann
 * @copyright 	Copyright (c) 2007 Aeron Glemann
 * @license		MIT
 * @link		http://electricprism.com/aeron/calendar
 *
 * Javascript - Autocompleter
 *
 * @package		autocompleter
 * @file		components/com_support/autocompleter.css
 * @file		components/com_support/autocompleter.js
 * @file		plugins/tageditor/autocompleter/observer.js
 * @file		plugins/tageditor/autocompleter/autocompleter.js
 * @file		plugins/tageditor/autocompleter/textboxlist.js
 * @author		Harald Kirschner <mail [at] digitarald.de>
 * @copyright	Harald Kirschner
 * @license		MIT-style license
 * @version		1.0rc4
 *
 * Javascript - HUB Framework
 *
 * @package		HUBzero
 * @file		templates/hubbasic/js/hub.js
 * @author		Shawn Rice
 * @author		Thomas Fuchs
 * @copyright	Copyright (c) 2005 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
 * @license
 *
 * Javascript - Balloons
 *
 * @package		Javascript - Balloons
 * @file		/templates/hubbasic/js/balloons.js
 * @license		MIT
 * @version		1.11
 * @link		http://www.uhleeka.com/archives/mootools/1.1/mootips/MooTips.v1.11.js
 *
 * Javascript - Slimbox
 *
 * @package		Javascript - Slimbox
 * @file		templates/hubbasic/js/slimbox.js
 * @auhtor		Christopher Beyls
 * @version		v1.41
 * @license		MIT-style license
 *
 * Javascript - Insertflash
 *
 * @package		Javascript - Insert Flash
 * @file		templates/hubbasic/js/insertflash.js
 * @copyright	Copyright(c) 2005-2006 Adobe Macromedia Software, LLC. All rights reserved.
 * @license
 *
 * Javascript - Clusterer
 *
 * @package		Javascript - Clusterer
 * @file		components/com_usage/maps/js/Clusterer2.js
 * @file		components/com_usage/maps/js/elabel.js
 * @author		Jef Poskanzer
 * @copyright 	Copyright 2005,2006 by Jef Poskanzer <jef@mail.acme.com>. All rights reserved.
 * @license		http://www.acme.com/license.html
 * @link		http://www.acme.com/javascript/
 *
 * Javascript - Elabel
 *
 * @package		Javascript - ELabel
 * @author 		Mike Williams
 * @author		Blackpool Community Church Javascript Team
 * @license		Creative Commons Licence http://creativecommons.org/licenses/by/2.0/uk
 *
 * Javascript - SqueezeBoxHub
 *
 * @package		Javascript - SqueezeBoxHub
 * @file		templates/hubbasic/js/modal.js
 * @author		Harald Kirschner
 * @author		Shawn Rice
 * @copyright   Copyright Harald Kirschner
 * @license		MIT-style license
 * @version		1.0rc1
 *
 * Javascript - Tooltips
 *
 * @package		Javascript - Tooltips
 * @file		templates/hubbasic/js/tooltips.js
 * @license		MIT
 * @version		1.11
 * @link		http://www.uhleeka.com/archives/mootools/1.1/mootips/MooTips.v1.11.js
 *
 * Javascript - Window.Growl
 *
 * @package		Javascript - Window.Growl
 * @file		templates/hubbasic/js/growl.js
 * @author		Daniel Mota aka IceBeat
 * @version		2.0
 * @link		http://icebeat.bitacoras.com/mootools/growl/1.1.html
 *
 * PHP - Math Wiki Class
 *
 * @package		math wiki
 * @author		Tomasz Wegrzanowski
 * @author		Brion Vibber
 * @copyright   Copyright 2003 Tomasz Wegrzanowski
 * @file		plugins/hubzero/wikiparser/math/math.php
 *
 * Javascript - Flash Player Version Detection
 *
 * @package 	Javascript - Flash Player Version Detection
 * @copyright	Copyright 2005-2007 Adobe Systems Incorporated.  All rights reserved.
 * @file		modules/mod_slideshow/images/AC_RunActiveContent.js
 *
 * Flash - Tweener
 *
 * @package		Tweener
 * @author		Zeh Fernando, Nate Chatellier, Arthur Debert
 * @version		1.31.71
 * @copyright	Copyright (c) 2006-2007 Zeh Fernando and Nate Chatellier
 * @license		Licensed under the MIT License
 * @link		http://code.google.com/p/tweener/
 *
 * iCalcreator
 *
 * @package     iCalcreator
 * @author      Kjell-Inge Gustafsson kigkonsult
 * @version     2.6
 * @copyright   copyright (c) 2007-2008 Kjell-Inge Gustafsson kigkonsult
 * @license     LGPL-2
 * @link        www.kigkonsult.se/iCalcreator/index.php
 */

==> hubzero-cms-2.0.0_2.0.0.0.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.0/cms/HUBZERO-CREDITS.php <==
<?php
/**
 * @package     hubzero-cms
 * @copyright   Copyright (c) 2005-2015 Purdue University. All rights reserved.
 * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// No direct access
defined('_HZEXE_') or die();

/**
 * HUBzero includes or is derivative of works distributed under the licenses listed below.
 *
 * CMS - Joomla!
 *
 * @author		Open Source Matters
 * @copyright	Copyright (C) 2005 - 2010 Open Source Matters. All rights reserved.
 * @license:	GNU/GPL, see lICENSE.php
 * @version		1.5.22
 * @link		http://joomlacode.org/gf/download/frsrelease/10547/41305/Joomla_1.5.12-Stable-Full_Package.zip
 *
 * Library - Open Flash Chart
 *
 * @package		Open Flash Chart
 * @copyright	Copyright (C) 2007 John Glazebrook
 * @license:	GNU/LGPL 2.1
 * @version:	2.0 (Hyperion)
 * @link		http://sourceforge.net/projects/openflashchart/files/open-flash-chart/open-flash-chart-2-hyperion.zip/download
 *
 * @package		SWFObject
 * @copuright	Copyright (c) 2007 Geoff Stearns, Michael Williams, and Bobby van der Sluis
 * @license     http://www.opensource.org/licenses/mit-license.php
 * @version		2.0
 * @link		http://code.google.com/p/swfobject/
 *
 * @package     Services_JSON
 * @author      Michal Migurski <mike-json@teczno.com>
 * @author      Matt Knapp <mdknapp[at]gmail[dot]com>
 * @author      Brett Stimmerman <brettstimmerman[at]gmail[dot]com>
 * @copyright   2005 Michal Migurski
 * @version     CVS: $Id: JSON.php,v 1.31 2006/06/28 05:54:17 migurski Exp $
 * @license     http://www.opensource.org/licenses/bsd-license.php
 * @link        http://pear.php.net/pepr/pepr-proposal-show.php?id=198
 *
 * @package		as3corelib
 * @copyright	Copyright(c) 2005 Adobe Systems Incorporated. All rights reserved.
 * @license		Adobe Systems Incorporated(r) Source Code License Agreement
 * @link		http://code.google.com/p/as3corelib/downloads/list
 *
 * @package		Equations - Main equations for the Tweener class
 * @author		Zeh Fernando, Nate Chatellier
 * @version		1.0.2
 * @license		MIT
 *
 * @package		Easing Equations
 * @author		Robert Penner
 * @copyright	Copyright 2001 Robert Penner. All rights reserved.
 * @license		Open source under the BSD License.
 *
 * @package 	Tweener
 * @author      Zeh Fernando, Nate Chatellier, Arthur Debert
 * @copuright	Copyright (c) 2006-2007 Zeh Fernando and Nate Chatellier
 * @version     1.26.62
 * @license		MIT
 *
 * @package		JSON
 * @author		Alcaraz Marc
 * @author		Trannie Carter
 * @copyright	Copyright (c) 2005 JSON.org
 * @version     1.0.0.0
 * @link		http://www.ekameleon.net
 *
 * Library - FPDF
 *
 * @package		fpdf
 * @author		Oliver Plathey
 * @license		permissive
 * @link		http://www.fpdf.org
 *
 * Library - NUSOAP
 *
 * @package		nusoap
 * @author		Dietrich Ayala
 * @author		Scott Nichol
 * @author		Ingo Fischer
 * @copyright	Copyright (c) 2002 NuSphere Corporation
 * @version		0.7.3
 * @license		LGPL
 *
 * Library - CAS
 *
 * @package		phpCAS
 * @author      Pascal Aubry.
 * @copyright	Copyright © 2003-2008, The ESUP-Portail consortium & the JA-SIG Collaborative. All rights reserved
 * @version		1.0.1
 * @license		BSD
 *
 * @package		domxml-php4-php5
 * @author		Alexandre Alapetite
 * @copyright	Copyright 2004
 * @license		Creative Commons "Attribution-ShareAlike 2.0 France" BY-SA (FR)
 * @link		http://alexandre.alapetite.net/doc-alex/domxml-php4-php5/
 *
 * CSS - Reset
 *
 * @package		reset css
 * @file		templates/hubbasic/css/reset.css
 * @copyright	Copyright (c) 2006, Yahoo! Inc. All rights reserved.
 * @license		Code licensed under the BSD License:
 * @link		http://developer.yahoo.net/yui/license.txt
 * @version		0.11.3
 *
 * Javascript - Calendar
 *
 * @package 	Javascript - Calendar
 * @file		components/com_events/calendar.css
 * @file		components/com_events/js/calendar.rc4.js
 * @author		Aeron Glemann
 * @copyright 	Copyright (c) 2007 Aeron Glemann
 * @license		MIT
 * @link		http://electricprism.com/aeron/calendar
 *
 * Javascript - Autocompleter
 *
 * @package		autocompleter
 * @file		components/com_support/autocompleter.css
 * @file		components/com_support/autocompleter.js
 * @file		plugins/tageditor/autocompleter/observer.js
 * @file		plugins/tageditor/autocompleter/autocompleter.js
 * @file		plugins/tageditor/autocompleter/textboxlist.js
 * @author		Harald Kirschner <mail [at] digitarald.de>
 * @copyright	Harald Kirschner
 * @license		MIT-style license
 * @version		1.0rc4
 *
 * Javascript - HUB Framework
 *
 * @package		HUBzero
 * @file		templates/hubbasic/js/hub.js
 * @author		Shawn Rice
 * @author		Thomas Fuchs
 * @copyright	Copyright (c) 2005 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
 * @license
 *
 * Javascript - Balloons
 *
 * @package		Javascript - Balloons
 * @file		/templates/hubbasic/js/balloons.js
 * @license		MIT
 * @version		1.11
 * @link		http://www.uhleeka.com/archives/mootools/1.1/mootips/MooTips.v1.11.js
 *
 * Javascript - Slimbox
 *
 * @package		Javascript - Slimbox
 * @file		templates/hubbasic/js/slimbox.js
 * @auhtor		Christopher Beyls
 * @version		v1.41
 * @license		MIT-style license
 *
 * Javascript - Insertflash
 *
 * @package		Javascript - Insert Flash
 * @file		templates/hubbasic/js/insertflash.js
 * @copyright	Copyright(c) 2005-2006 Adobe Macromedia Software, LLC. All rights reserved.
 * @license
 *
 * Javascript - Clusterer
 *
 * @package		Javascript - Clusterer
 * @file		components/com_usage/maps/js/Clusterer2.js
 * @file		components/com_usage/maps/js/elabel.js
 * @author		Jef Poskanzer
 * @copyright 	Copyright 2005,2006 by Jef Poskanzer <jef@mail.acme.com>. All rights reserved.
 * @license		http://www.acme.com/license.html
 * @link		http://www.acme.com/javascript/
 *
 * Javascript - Elabel
 *
 * @package		Javascript - ELabel
 * @author 		Mike Williams
 * @author		Blackpool Community Church Javascript Team
 * @license		Creative Commons Licence http://creativecommons.org/licenses/by/2.0/uk
 *
 * Javascript - SqueezeBoxHub
 *
 * @package		Javascript - SqueezeBoxHub
 * @file		templates/hubbasic/js/modal.js
 * @author		Harald Kirschner
 * @author		Shawn Rice
 * @copyright   Copyright Harald Kirschner
 * @license		MIT-style license
 * @version		1.0rc1
 *
 * Javascript - Tooltips
 *
 * @package		Javascript - Tooltips
 * @file		templates/hubbasic/js/tooltips.js
 * @license		MIT
 * @version		1.11
 * @link		http://www.uhleeka.com/archives/mootools/1.1/mootips/MooTips.v1.11.js
 *
 * Javascript - Window.Growl
 *
 * @package		Javascript - Window.Growl
 * @file		templates/hubbasic/js/growl.js
 * @author		Daniel Mota aka IceBeat
 * @version		2.0
 * @link		http://icebeat.bitacoras.com/mootools/growl/1.1.html
 *
 * PHP - Math Wiki Class
 *
 * @package		math wiki
 * @author		Tomasz Wegrzanowski
 * @author		Brion Vibber
 * @copyright   Copyright 2003 Tomasz Wegrzanowski
 * @file		plugins/hubzero/wikiparser/math/math.php
 *
 * Javascript - Flash Player Version Detection
 *
 * @package 	Javascript - Flash Player Version Detection
 * @copyright	Copyright 2005-2007 Adobe Systems Incorporated.  All rights reserved.
 * @file		modules/mod_slideshow/images/AC_RunActiveContent.js
 *
 * Flash - Tweener
 *
 * @package		Tweener
 * @author		Zeh Fernando, Nate Chatellier, Arthur Debert
 * @version		1.31.71
 * @copyright	Copyright (c) 2006-2007 Zeh Fernando and Nate Chatellier
 * @license		Licensed under the MIT License
 * @link		http://code.google.com/p/tweener/
 *
 * iCalcreator
 *
 * @package     iCalcreator
 * @author      Kjell-Inge Gustafsson kigkonsult
 * @version     2.6
 * @copyright   copyright (c) 2007-2008 Kjell-Inge Gustafsson kigkonsult
 * @license     LGPL-2
 * @link        www.kigkonsult.se/iCalcreator/index.php
 */
